#ifndef NT2_INCLUDE_FUNCTIONS_ATANPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ATANPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/atanpi.hpp>

#endif
